==> resim_open_core-0.1.0-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/reports/list_report_metrics_data_for_report_metrics_data_i_ds.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...types import Unset
from ...models.list_report_metrics_data_output import ListReportMetricsDataOutput


def _get_kwargs(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["pageSize"] = page_size

    params["pageToken"] = page_token

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_id}/reports/{report_id}/metricsData/{metrics_data_id}".format(
            project_id=project_id,
            report_id=report_id,
            metrics_data_id=metrics_data_id,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ListReportMetricsDataOutput.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,
) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    """Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ListReportMetricsDataOutput]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        report_id=report_id,
        metrics_data_id=metrics_data_id,
        page_size=page_size,
        page_token=page_token,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    """Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ListReportMetricsDataOutput]
    """

    return sync_detailed(
        project_id=project_id,
        report_id=report_id,
        metrics_data_id=metrics_data_id,
        client=client,
        page_size=page_size,
        page_token=page_token,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,
) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    """Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ListReportMetricsDataOutput]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        report_id=report_id,
        metrics_data_id=metrics_data_id,
        page_size=page_size,
        page_token=page_token,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    """Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ListReportMetricsDataOutput]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            report_id=report_id,
            metrics_data_id=metrics_data_id,
            client=client,
            page_size=page_size,
            page_token=page_token,
        )
    ).parsed

==> resim_open_core-0.2.0-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/reports/list_report_metrics_data_for_report_metrics_data_i_ds.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.list_report_metrics_data_output import ListReportMetricsDataOutput
from typing import Dict
from typing import cast
from ...types import UNSET, Unset
from typing import cast, List
from typing import Union



def _get_kwargs(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,

) -> Dict[str, Any]:
    

    

    params: Dict[str, Any] = {}

    params["pageSize"] = page_size

    params["pageToken"] = page_token


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_id}/reports/{report_id}/metricsData/{metrics_data_id}".format(project_id=project_id,report_id=report_id,metrics_data_id=metrics_data_id,),
        "params": params,
    }


    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ListReportMetricsDataOutput.from_dict(response.json())



        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,

) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    """  Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ListReportMetricsDataOutput]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
report_id=report_id,
metrics_data_id=metrics_data_id,
page_size=page_size,
page_token=page_token,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,

) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    """  Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ListReportMetricsDataOutput]
     """


    return sync_detailed(
        project_id=project_id,
report_id=report_id,
metrics_data_id=metrics_data_id,
client=client,
page_size=page_size,
page_token=page_token,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,

) -> Response[Union[Any, ListReportMetricsDataOutput]]:
    """  Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ListReportMetricsDataOutput]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
report_id=report_id,
metrics_data_id=metrics_data_id,
page_size=page_size,
page_token=page_token,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    report_id: str,
    metrics_data_id: List[str],
    *,
    client: AuthenticatedClient,
    page_size: Union[Unset, int] = UNSET,
    page_token: Union[Unset, str] = UNSET,

) -> Optional[Union[Any, ListReportMetricsDataOutput]]:
    """  Lists the report metrics data associated with given report metrics data IDs

    Args:
        project_id (str):
        report_id (str):
        metrics_data_id (List[str]):
        page_size (Union[Unset, int]):
        page_token (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ListReportMetricsDataOutput]
     """


    return (await asyncio_detailed(
        project_id=project_id,
report_id=report_id,
metrics_data_id=metrics_data_id,
client=client,
page_size=page_size,
page_token=page_token,

    )).parsed
